==> jc-1.4.0.tar.gz: javax/swing/event/UndoableEditEvent.h <==
// public class javax.swing.event.UndoableEditEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 280246500af3c5cc javax_swing_event_UndoableEditEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_UndoableEditEvent_H_
#define _JC_javax_swing_event_UndoableEditEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_undo_UndoableEdit$object;

// Typedefs
typedef struct _jc_javax_swing_event_UndoableEditEvent$sub_refs	_jc_javax_swing_event_UndoableEditEvent$sub_refs;
typedef struct _jc_javax_swing_event_UndoableEditEvent$sub_nonrefs	_jc_javax_swing_event_UndoableEditEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_UndoableEditEvent$refs	_jc_javax_swing_event_UndoableEditEvent$refs;
typedef struct _jc_javax_swing_event_UndoableEditEvent$nonrefs	_jc_javax_swing_event_UndoableEditEvent$nonrefs;
typedef struct _jc_javax_swing_event_UndoableEditEvent$object	_jc_javax_swing_event_UndoableEditEvent$object;

typedef struct _jc_javax_swing_event_UndoableEditEvent$fields_struct	_jc_javax_swing_event_UndoableEditEvent$fields_struct;
typedef const struct _jc_javax_swing_event_UndoableEditEvent$vmethods	_jc_javax_swing_event_UndoableEditEvent$vmethods;
typedef const struct _jc_javax_swing_event_UndoableEditEvent$vtable	_jc_javax_swing_event_UndoableEditEvent$vtable;
typedef const struct _jc_javax_swing_event_UndoableEditEvent$vtype	_jc_javax_swing_event_UndoableEditEvent$vtype;

// Class fields structure
struct _jc_javax_swing_event_UndoableEditEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_event_UndoableEditEvent$fields_struct _jc_javax_swing_event_UndoableEditEvent$class_fields;

// Constructors
extern void _jc_javax_swing_event_UndoableEditEvent$method$_init$40182ac079703529(_jc_env *, struct _jc_javax_swing_event_UndoableEditEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_javax_swing_event_UndoableEditEvent$method$getEdit$96d9936227eea99c(_jc_env *, struct _jc_javax_swing_event_UndoableEditEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_UndoableEditEvent$method_info$getEdit$96d9936227eea99c;

// Virtual methods structure
struct _jc_javax_swing_event_UndoableEditEvent$vmethods {
	struct _jc_object	*(*getEdit$96d9936227eea99c)(_jc_env *, struct _jc_javax_swing_event_UndoableEditEvent$object *);
};

// Vtable
struct _jc_javax_swing_event_UndoableEditEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_UndoableEditEvent$vmethods	javax_swing_event_UndoableEditEvent;
};

// Vtype
struct _jc_javax_swing_event_UndoableEditEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_UndoableEditEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_UndoableEditEvent$sub_refs {
	struct _jc_object	*edit;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_UndoableEditEvent$refs {
    _jc_javax_swing_event_UndoableEditEvent$sub_refs	javax_swing_event_UndoableEditEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_UndoableEditEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_UndoableEditEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_UndoableEditEvent$sub_nonrefs	javax_swing_event_UndoableEditEvent;
};

// Object instance structure
struct _jc_javax_swing_event_UndoableEditEvent$object {
	_jc_javax_swing_event_UndoableEditEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_UndoableEditEvent$vtype	*vtype;
	_jc_javax_swing_event_UndoableEditEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_UndoableEditEvent$vtype _jc_javax_swing_event_UndoableEditEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_UndoableEditEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_UndoableEditEvent$class_object;

#endif	/* _JC_javax_swing_event_UndoableEditEvent_H_ */

==> jc-1.4.6.tar.gz: javax/swing/event/UndoableEditEvent.h <==
// public class javax.swing.event.UndoableEditEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 280246500af3c5cc javax_swing_event_UndoableEditEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_UndoableEditEvent_H_
#define _JC_javax_swing_event_UndoableEditEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_undo_UndoableEdit$object;

// Typedefs
typedef struct _jc_javax_swing_event_UndoableEditEvent$sub_refs	_jc_javax_swing_event_UndoableEditEvent$sub_refs;
typedef struct _jc_javax_swing_event_UndoableEditEvent$sub_nonrefs	_jc_javax_swing_event_UndoableEditEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_UndoableEditEvent$refs	_jc_javax_swing_event_UndoableEditEvent$refs;
typedef struct _jc_javax_swing_event_UndoableEditEvent$nonrefs	_jc_javax_swing_event_UndoableEditEvent$nonrefs;
typedef struct _jc_javax_swing_event_UndoableEditEvent$object	_jc_javax_swing_event_UndoableEditEvent$object;

typedef struct _jc_javax_swing_event_UndoableEditEvent$fields_struct	_jc_javax_swing_event_UndoableEditEvent$fields_struct;
typedef const struct _jc_javax_swing_event_UndoableEditEvent$vmethods	_jc_javax_swing_event_UndoableEditEvent$vmethods;
typedef const struct _jc_javax_swing_event_UndoableEditEvent$vtable	_jc_javax_swing_event_UndoableEditEvent$vtable;
typedef const struct _jc_javax_swing_event_UndoableEditEvent$vtype	_jc_javax_swing_event_UndoableEditEvent$vtype;

// Class fields structure
struct _jc_javax_swing_event_UndoableEditEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_event_UndoableEditEvent$fields_struct _jc_javax_swing_event_UndoableEditEvent$class_fields;

// Constructors
extern void _jc_javax_swing_event_UndoableEditEvent$method$_init$40182ac079703529(_jc_env *, struct _jc_javax_swing_event_UndoableEditEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_swing_event_UndoableEditEvent$method$getEdit$96d9936227eea99c(_jc_env *, struct _jc_javax_swing_event_UndoableEditEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_UndoableEditEvent$method_info$getEdit$96d9936227eea99c;

// Virtual methods structure
struct _jc_javax_swing_event_UndoableEditEvent$vmethods {
	struct _jc_object	*(*getEdit$96d9936227eea99c)(_jc_env *, struct _jc_javax_swing_event_UndoableEditEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_UndoableEditEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_UndoableEditEvent$vmethods	javax_swing_event_UndoableEditEvent;
};

// Vtype
struct _jc_javax_swing_event_UndoableEditEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_UndoableEditEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_UndoableEditEvent$sub_refs {
	struct _jc_object	*edit;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_UndoableEditEvent$refs {
    _jc_javax_swing_event_UndoableEditEvent$sub_refs	javax_swing_event_UndoableEditEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_UndoableEditEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_UndoableEditEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_UndoableEditEvent$sub_nonrefs	javax_swing_event_UndoableEditEvent;
};

// Object instance structure
struct _jc_javax_swing_event_UndoableEditEvent$object {
	_jc_javax_swing_event_UndoableEditEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_UndoableEditEvent$vtype	*vtype;
	_jc_javax_swing_event_UndoableEditEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_UndoableEditEvent$vtype _jc_javax_swing_event_UndoableEditEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_UndoableEditEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_UndoableEditEvent$class_object;

#endif	/* _JC_javax_swing_event_UndoableEditEvent_H_ */
